FlanaBot
========

.. image:: https://img.shields.io/github/license/AlberLC/flanabot?style=flat
    :target: https://github.com/AlberLC/flanabot/blob/main/LICENSE
    :alt: License

Flanagan's bot.

Installation
------------
Python 3.10 or higher is required.

.. code-block:: python

    pip install flanabot